param I; # number of fabs
param J; # number of items
param K; # number of k orders

param S{k in 1..K}; # the splitting cost of order K
param R{k in 1..K}; # revenue from order k if it's completed
param H{i in 1..I, j in 1..J}; # the production rate that Fab i produces item j
param Q{k in 1..K, j in 1..J}; # the demand quantity of item j in order k
param C{i in 1..I}; # the capacity of fab i

var x{i in 1..I, j in 1..J, k in 1..K}; # the machine hours that fab i produce item j for order k
var y{k in 1..K} binary; # whether the order k is completed
var z{i in 1..I, k in 1..K} binary; # whether fab i produces for the order k

maximize Sale:sum{k in 1..K}(R[k]*y[k]-(sum{i in 1..I}(z[i,k]) - y[k])*S[k]);

subject to Capacity{i in 1..I}: sum{j in 1..J, k in 1..K}x[i,j,k] <= C[i];  # Capacity Constraint
subject to OrderFullfill{j in 1..J, k in 1..K}: sum{i in 1..I}(x[i,j,k]*H[i,j]) >= Q[k,j]*y[k];  # Order Fullfillment
subject to IsFabProduce{i in 1..I, k in 1..K}: sum{j in 1..J}(x[i,j,k]*H[i,j]) <= sum{j in 1..J}(Q[k,j])*z[i,k]; # whether fab i produces in order k

subject to nonneg{i in 1..I, j in 1..J, k in 1..K}: x[i,j,k] >= 0;

